# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class IntegrationType(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationType - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'provider': 'str',
            'category': 'str',
            'images': 'list[UserImage]',
            'config_properties_schema_uri': 'str',
            'config_advanced_schema_uri': 'str',
            'help_uri': 'str',
            'terms_of_service_uri': 'str',
            'vendor_name': 'str',
            'vendor_website_uri': 'str',
            'marketplace_uri': 'str',
            'faq_uri': 'str',
            'privacy_policy_uri': 'str',
            'support_contact_uri': 'str',
            'sales_contact_uri': 'str',
            'help_links': 'list[HelpLink]',
            'credentials': 'dict(str, CredentialSpecification)',
            'non_installable': 'bool',
            'max_instances': 'int',
            'user_permissions': 'list[str]',
            'vendor_o_auth_client_ids': 'list[str]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'provider': 'provider',
            'category': 'category',
            'images': 'images',
            'config_properties_schema_uri': 'configPropertiesSchemaUri',
            'config_advanced_schema_uri': 'configAdvancedSchemaUri',
            'help_uri': 'helpUri',
            'terms_of_service_uri': 'termsOfServiceUri',
            'vendor_name': 'vendorName',
            'vendor_website_uri': 'vendorWebsiteUri',
            'marketplace_uri': 'marketplaceUri',
            'faq_uri': 'faqUri',
            'privacy_policy_uri': 'privacyPolicyUri',
            'support_contact_uri': 'supportContactUri',
            'sales_contact_uri': 'salesContactUri',
            'help_links': 'helpLinks',
            'credentials': 'credentials',
            'non_installable': 'nonInstallable',
            'max_instances': 'maxInstances',
            'user_permissions': 'userPermissions',
            'vendor_o_auth_client_ids': 'vendorOAuthClientIds',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._provider = None
        self._category = None
        self._images = None
        self._config_properties_schema_uri = None
        self._config_advanced_schema_uri = None
        self._help_uri = None
        self._terms_of_service_uri = None
        self._vendor_name = None
        self._vendor_website_uri = None
        self._marketplace_uri = None
        self._faq_uri = None
        self._privacy_policy_uri = None
        self._support_contact_uri = None
        self._sales_contact_uri = None
        self._help_links = None
        self._credentials = None
        self._non_installable = None
        self._max_instances = None
        self._user_permissions = None
        self._vendor_o_auth_client_ids = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this IntegrationType.
        The ID of the integration type.

        :return: The id of this IntegrationType.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IntegrationType.
        The ID of the integration type.

        :param id: The id of this IntegrationType.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this IntegrationType.


        :return: The name of this IntegrationType.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IntegrationType.


        :param name: The name of this IntegrationType.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this IntegrationType.
        Description of the integration type.

        :return: The description of this IntegrationType.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this IntegrationType.
        Description of the integration type.

        :param description: The description of this IntegrationType.
        :type: str
        """
        
        self._description = description

    @property
    def provider(self):
        """
        Gets the provider of this IntegrationType.
        PureCloud provider of the integration type.

        :return: The provider of this IntegrationType.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this IntegrationType.
        PureCloud provider of the integration type.

        :param provider: The provider of this IntegrationType.
        :type: str
        """
        
        self._provider = provider

    @property
    def category(self):
        """
        Gets the category of this IntegrationType.
        Category describing the integration type.

        :return: The category of this IntegrationType.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this IntegrationType.
        Category describing the integration type.

        :param category: The category of this IntegrationType.
        :type: str
        """
        
        self._category = category

    @property
    def images(self):
        """
        Gets the images of this IntegrationType.
        Collection of logos.

        :return: The images of this IntegrationType.
        :rtype: list[UserImage]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this IntegrationType.
        Collection of logos.

        :param images: The images of this IntegrationType.
        :type: list[UserImage]
        """
        
        self._images = images

    @property
    def config_properties_schema_uri(self):
        """
        Gets the config_properties_schema_uri of this IntegrationType.
        URI of the schema describing the key-value properties needed to configure an integration of this type.

        :return: The config_properties_schema_uri of this IntegrationType.
        :rtype: str
        """
        return self._config_properties_schema_uri

    @config_properties_schema_uri.setter
    def config_properties_schema_uri(self, config_properties_schema_uri):
        """
        Sets the config_properties_schema_uri of this IntegrationType.
        URI of the schema describing the key-value properties needed to configure an integration of this type.

        :param config_properties_schema_uri: The config_properties_schema_uri of this IntegrationType.
        :type: str
        """
        
        self._config_properties_schema_uri = config_properties_schema_uri

    @property
    def config_advanced_schema_uri(self):
        """
        Gets the config_advanced_schema_uri of this IntegrationType.
        URI of the schema describing the advanced JSON document needed to configure an integration of this type.

        :return: The config_advanced_schema_uri of this IntegrationType.
        :rtype: str
        """
        return self._config_advanced_schema_uri

    @config_advanced_schema_uri.setter
    def config_advanced_schema_uri(self, config_advanced_schema_uri):
        """
        Sets the config_advanced_schema_uri of this IntegrationType.
        URI of the schema describing the advanced JSON document needed to configure an integration of this type.

        :param config_advanced_schema_uri: The config_advanced_schema_uri of this IntegrationType.
        :type: str
        """
        
        self._config_advanced_schema_uri = config_advanced_schema_uri

    @property
    def help_uri(self):
        """
        Gets the help_uri of this IntegrationType.
        URI of a page with more information about the integration type

        :return: The help_uri of this IntegrationType.
        :rtype: str
        """
        return self._help_uri

    @help_uri.setter
    def help_uri(self, help_uri):
        """
        Sets the help_uri of this IntegrationType.
        URI of a page with more information about the integration type

        :param help_uri: The help_uri of this IntegrationType.
        :type: str
        """
        
        self._help_uri = help_uri

    @property
    def terms_of_service_uri(self):
        """
        Gets the terms_of_service_uri of this IntegrationType.
        URI of a page with terms and conditions for the integration type

        :return: The terms_of_service_uri of this IntegrationType.
        :rtype: str
        """
        return self._terms_of_service_uri

    @terms_of_service_uri.setter
    def terms_of_service_uri(self, terms_of_service_uri):
        """
        Sets the terms_of_service_uri of this IntegrationType.
        URI of a page with terms and conditions for the integration type

        :param terms_of_service_uri: The terms_of_service_uri of this IntegrationType.
        :type: str
        """
        
        self._terms_of_service_uri = terms_of_service_uri

    @property
    def vendor_name(self):
        """
        Gets the vendor_name of this IntegrationType.
        Name of the vendor of this integration type

        :return: The vendor_name of this IntegrationType.
        :rtype: str
        """
        return self._vendor_name

    @vendor_name.setter
    def vendor_name(self, vendor_name):
        """
        Sets the vendor_name of this IntegrationType.
        Name of the vendor of this integration type

        :param vendor_name: The vendor_name of this IntegrationType.
        :type: str
        """
        
        self._vendor_name = vendor_name

    @property
    def vendor_website_uri(self):
        """
        Gets the vendor_website_uri of this IntegrationType.
        URI of the vendor's website

        :return: The vendor_website_uri of this IntegrationType.
        :rtype: str
        """
        return self._vendor_website_uri

    @vendor_website_uri.setter
    def vendor_website_uri(self, vendor_website_uri):
        """
        Sets the vendor_website_uri of this IntegrationType.
        URI of the vendor's website

        :param vendor_website_uri: The vendor_website_uri of this IntegrationType.
        :type: str
        """
        
        self._vendor_website_uri = vendor_website_uri

    @property
    def marketplace_uri(self):
        """
        Gets the marketplace_uri of this IntegrationType.
        URI of the marketplace listing for this integration type

        :return: The marketplace_uri of this IntegrationType.
        :rtype: str
        """
        return self._marketplace_uri

    @marketplace_uri.setter
    def marketplace_uri(self, marketplace_uri):
        """
        Sets the marketplace_uri of this IntegrationType.
        URI of the marketplace listing for this integration type

        :param marketplace_uri: The marketplace_uri of this IntegrationType.
        :type: str
        """
        
        self._marketplace_uri = marketplace_uri

    @property
    def faq_uri(self):
        """
        Gets the faq_uri of this IntegrationType.
        URI of frequently asked questions about the integration type

        :return: The faq_uri of this IntegrationType.
        :rtype: str
        """
        return self._faq_uri

    @faq_uri.setter
    def faq_uri(self, faq_uri):
        """
        Sets the faq_uri of this IntegrationType.
        URI of frequently asked questions about the integration type

        :param faq_uri: The faq_uri of this IntegrationType.
        :type: str
        """
        
        self._faq_uri = faq_uri

    @property
    def privacy_policy_uri(self):
        """
        Gets the privacy_policy_uri of this IntegrationType.
        URI of a privacy policy for users of the integration type

        :return: The privacy_policy_uri of this IntegrationType.
        :rtype: str
        """
        return self._privacy_policy_uri

    @privacy_policy_uri.setter
    def privacy_policy_uri(self, privacy_policy_uri):
        """
        Sets the privacy_policy_uri of this IntegrationType.
        URI of a privacy policy for users of the integration type

        :param privacy_policy_uri: The privacy_policy_uri of this IntegrationType.
        :type: str
        """
        
        self._privacy_policy_uri = privacy_policy_uri

    @property
    def support_contact_uri(self):
        """
        Gets the support_contact_uri of this IntegrationType.
        URI for vendor support

        :return: The support_contact_uri of this IntegrationType.
        :rtype: str
        """
        return self._support_contact_uri

    @support_contact_uri.setter
    def support_contact_uri(self, support_contact_uri):
        """
        Sets the support_contact_uri of this IntegrationType.
        URI for vendor support

        :param support_contact_uri: The support_contact_uri of this IntegrationType.
        :type: str
        """
        
        self._support_contact_uri = support_contact_uri

    @property
    def sales_contact_uri(self):
        """
        Gets the sales_contact_uri of this IntegrationType.
        URI for vendor sales information

        :return: The sales_contact_uri of this IntegrationType.
        :rtype: str
        """
        return self._sales_contact_uri

    @sales_contact_uri.setter
    def sales_contact_uri(self, sales_contact_uri):
        """
        Sets the sales_contact_uri of this IntegrationType.
        URI for vendor sales information

        :param sales_contact_uri: The sales_contact_uri of this IntegrationType.
        :type: str
        """
        
        self._sales_contact_uri = sales_contact_uri

    @property
    def help_links(self):
        """
        Gets the help_links of this IntegrationType.
        List of links to additional help resources

        :return: The help_links of this IntegrationType.
        :rtype: list[HelpLink]
        """
        return self._help_links

    @help_links.setter
    def help_links(self, help_links):
        """
        Sets the help_links of this IntegrationType.
        List of links to additional help resources

        :param help_links: The help_links of this IntegrationType.
        :type: list[HelpLink]
        """
        
        self._help_links = help_links

    @property
    def credentials(self):
        """
        Gets the credentials of this IntegrationType.
        Map of credentials for integrations of this type. The key is the name of a credential that can be provided in the credentials property of the integration configuration.

        :return: The credentials of this IntegrationType.
        :rtype: dict(str, CredentialSpecification)
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this IntegrationType.
        Map of credentials for integrations of this type. The key is the name of a credential that can be provided in the credentials property of the integration configuration.

        :param credentials: The credentials of this IntegrationType.
        :type: dict(str, CredentialSpecification)
        """
        
        self._credentials = credentials

    @property
    def non_installable(self):
        """
        Gets the non_installable of this IntegrationType.
        Indicates if the integration type is installable or not.

        :return: The non_installable of this IntegrationType.
        :rtype: bool
        """
        return self._non_installable

    @non_installable.setter
    def non_installable(self, non_installable):
        """
        Sets the non_installable of this IntegrationType.
        Indicates if the integration type is installable or not.

        :param non_installable: The non_installable of this IntegrationType.
        :type: bool
        """
        
        self._non_installable = non_installable

    @property
    def max_instances(self):
        """
        Gets the max_instances of this IntegrationType.
        The maximum number of integration instances allowable for this integration type

        :return: The max_instances of this IntegrationType.
        :rtype: int
        """
        return self._max_instances

    @max_instances.setter
    def max_instances(self, max_instances):
        """
        Sets the max_instances of this IntegrationType.
        The maximum number of integration instances allowable for this integration type

        :param max_instances: The max_instances of this IntegrationType.
        :type: int
        """
        
        self._max_instances = max_instances

    @property
    def user_permissions(self):
        """
        Gets the user_permissions of this IntegrationType.
        List of permissions required to permit user access to the integration type.

        :return: The user_permissions of this IntegrationType.
        :rtype: list[str]
        """
        return self._user_permissions

    @user_permissions.setter
    def user_permissions(self, user_permissions):
        """
        Sets the user_permissions of this IntegrationType.
        List of permissions required to permit user access to the integration type.

        :param user_permissions: The user_permissions of this IntegrationType.
        :type: list[str]
        """
        
        self._user_permissions = user_permissions

    @property
    def vendor_o_auth_client_ids(self):
        """
        Gets the vendor_o_auth_client_ids of this IntegrationType.
        List of OAuth Client IDs that must be authorized when the integration is created.

        :return: The vendor_o_auth_client_ids of this IntegrationType.
        :rtype: list[str]
        """
        return self._vendor_o_auth_client_ids

    @vendor_o_auth_client_ids.setter
    def vendor_o_auth_client_ids(self, vendor_o_auth_client_ids):
        """
        Sets the vendor_o_auth_client_ids of this IntegrationType.
        List of OAuth Client IDs that must be authorized when the integration is created.

        :param vendor_o_auth_client_ids: The vendor_o_auth_client_ids of this IntegrationType.
        :type: list[str]
        """
        
        self._vendor_o_auth_client_ids = vendor_o_auth_client_ids

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IntegrationType.
        The URI for this object

        :return: The self_uri of this IntegrationType.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IntegrationType.
        The URI for this object

        :param self_uri: The self_uri of this IntegrationType.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TrusteeBillingOverview(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TrusteeBillingOverview - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'organization': 'NamedEntity',
            'currency': 'str',
            'enabled_products': 'list[str]',
            'subscription_type': 'str',
            'ramp_period_start_date': 'datetime',
            'ramp_period_end_date': 'datetime',
            'billing_period_start_date': 'datetime',
            'billing_period_end_date': 'datetime',
            'usages': 'list[SubscriptionOverviewUsage]',
            'contract_amendment_date': 'datetime',
            'contract_effective_date': 'datetime',
            'contract_end_date': 'datetime',
            'minimum_monthly_amount': 'str',
            'in_ramp_period': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'organization': 'organization',
            'currency': 'currency',
            'enabled_products': 'enabledProducts',
            'subscription_type': 'subscriptionType',
            'ramp_period_start_date': 'rampPeriodStartDate',
            'ramp_period_end_date': 'rampPeriodEndDate',
            'billing_period_start_date': 'billingPeriodStartDate',
            'billing_period_end_date': 'billingPeriodEndDate',
            'usages': 'usages',
            'contract_amendment_date': 'contractAmendmentDate',
            'contract_effective_date': 'contractEffectiveDate',
            'contract_end_date': 'contractEndDate',
            'minimum_monthly_amount': 'minimumMonthlyAmount',
            'in_ramp_period': 'inRampPeriod',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._organization = None
        self._currency = None
        self._enabled_products = None
        self._subscription_type = None
        self._ramp_period_start_date = None
        self._ramp_period_end_date = None
        self._billing_period_start_date = None
        self._billing_period_end_date = None
        self._usages = None
        self._contract_amendment_date = None
        self._contract_effective_date = None
        self._contract_end_date = None
        self._minimum_monthly_amount = None
        self._in_ramp_period = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TrusteeBillingOverview.
        The globally unique identifier for the object.

        :return: The id of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TrusteeBillingOverview.
        The globally unique identifier for the object.

        :param id: The id of this TrusteeBillingOverview.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TrusteeBillingOverview.


        :return: The name of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TrusteeBillingOverview.


        :param name: The name of this TrusteeBillingOverview.
        :type: str
        """
        
        self._name = name

    @property
    def organization(self):
        """
        Gets the organization of this TrusteeBillingOverview.
        Organization

        :return: The organization of this TrusteeBillingOverview.
        :rtype: NamedEntity
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this TrusteeBillingOverview.
        Organization

        :param organization: The organization of this TrusteeBillingOverview.
        :type: NamedEntity
        """
        
        self._organization = organization

    @property
    def currency(self):
        """
        Gets the currency of this TrusteeBillingOverview.
        The currency type.

        :return: The currency of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this TrusteeBillingOverview.
        The currency type.

        :param currency: The currency of this TrusteeBillingOverview.
        :type: str
        """
        
        self._currency = currency

    @property
    def enabled_products(self):
        """
        Gets the enabled_products of this TrusteeBillingOverview.
        The charge short names for products enabled during the specified period.

        :return: The enabled_products of this TrusteeBillingOverview.
        :rtype: list[str]
        """
        return self._enabled_products

    @enabled_products.setter
    def enabled_products(self, enabled_products):
        """
        Sets the enabled_products of this TrusteeBillingOverview.
        The charge short names for products enabled during the specified period.

        :param enabled_products: The enabled_products of this TrusteeBillingOverview.
        :type: list[str]
        """
        
        self._enabled_products = enabled_products

    @property
    def subscription_type(self):
        """
        Gets the subscription_type of this TrusteeBillingOverview.
        The subscription type.

        :return: The subscription_type of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._subscription_type

    @subscription_type.setter
    def subscription_type(self, subscription_type):
        """
        Sets the subscription_type of this TrusteeBillingOverview.
        The subscription type.

        :param subscription_type: The subscription_type of this TrusteeBillingOverview.
        :type: str
        """
        allowed_values = ["ININ", "MONTH_TO_MONTH", "FREE_TRIAL_MONTH_TO_MONTH", "PREPAY_MONTHLY_COMMITMENT", "PREPAY", "DEV_ORG_MONTH_TO_MONTH", "DEV_ORG_PREPAY_MONTHLY_COMMITMENT", "DEV_ORG_PREPAY"]
        if subscription_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for subscription_type -> " + subscription_type)
            self._subscription_type = "outdated_sdk_version"
        else:
            self._subscription_type = subscription_type

    @property
    def ramp_period_start_date(self):
        """
        Gets the ramp_period_start_date of this TrusteeBillingOverview.
        Date-time the ramp period starts. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The ramp_period_start_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._ramp_period_start_date

    @ramp_period_start_date.setter
    def ramp_period_start_date(self, ramp_period_start_date):
        """
        Sets the ramp_period_start_date of this TrusteeBillingOverview.
        Date-time the ramp period starts. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param ramp_period_start_date: The ramp_period_start_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._ramp_period_start_date = ramp_period_start_date

    @property
    def ramp_period_end_date(self):
        """
        Gets the ramp_period_end_date of this TrusteeBillingOverview.
        Date-time the ramp period ends. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The ramp_period_end_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._ramp_period_end_date

    @ramp_period_end_date.setter
    def ramp_period_end_date(self, ramp_period_end_date):
        """
        Sets the ramp_period_end_date of this TrusteeBillingOverview.
        Date-time the ramp period ends. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param ramp_period_end_date: The ramp_period_end_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._ramp_period_end_date = ramp_period_end_date

    @property
    def billing_period_start_date(self):
        """
        Gets the billing_period_start_date of this TrusteeBillingOverview.
        Date-time the billing period started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The billing_period_start_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._billing_period_start_date

    @billing_period_start_date.setter
    def billing_period_start_date(self, billing_period_start_date):
        """
        Sets the billing_period_start_date of this TrusteeBillingOverview.
        Date-time the billing period started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param billing_period_start_date: The billing_period_start_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._billing_period_start_date = billing_period_start_date

    @property
    def billing_period_end_date(self):
        """
        Gets the billing_period_end_date of this TrusteeBillingOverview.
        Date-time the billing period ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The billing_period_end_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._billing_period_end_date

    @billing_period_end_date.setter
    def billing_period_end_date(self, billing_period_end_date):
        """
        Sets the billing_period_end_date of this TrusteeBillingOverview.
        Date-time the billing period ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param billing_period_end_date: The billing_period_end_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._billing_period_end_date = billing_period_end_date

    @property
    def usages(self):
        """
        Gets the usages of this TrusteeBillingOverview.
        Usages for the specified period.

        :return: The usages of this TrusteeBillingOverview.
        :rtype: list[SubscriptionOverviewUsage]
        """
        return self._usages

    @usages.setter
    def usages(self, usages):
        """
        Sets the usages of this TrusteeBillingOverview.
        Usages for the specified period.

        :param usages: The usages of this TrusteeBillingOverview.
        :type: list[SubscriptionOverviewUsage]
        """
        
        self._usages = usages

    @property
    def contract_amendment_date(self):
        """
        Gets the contract_amendment_date of this TrusteeBillingOverview.
        Date-time the contract was last amended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The contract_amendment_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._contract_amendment_date

    @contract_amendment_date.setter
    def contract_amendment_date(self, contract_amendment_date):
        """
        Sets the contract_amendment_date of this TrusteeBillingOverview.
        Date-time the contract was last amended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param contract_amendment_date: The contract_amendment_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._contract_amendment_date = contract_amendment_date

    @property
    def contract_effective_date(self):
        """
        Gets the contract_effective_date of this TrusteeBillingOverview.
        Date-time the contract became effective. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The contract_effective_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._contract_effective_date

    @contract_effective_date.setter
    def contract_effective_date(self, contract_effective_date):
        """
        Sets the contract_effective_date of this TrusteeBillingOverview.
        Date-time the contract became effective. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param contract_effective_date: The contract_effective_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._contract_effective_date = contract_effective_date

    @property
    def contract_end_date(self):
        """
        Gets the contract_end_date of this TrusteeBillingOverview.
        Date-time the contract ends. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The contract_end_date of this TrusteeBillingOverview.
        :rtype: datetime
        """
        return self._contract_end_date

    @contract_end_date.setter
    def contract_end_date(self, contract_end_date):
        """
        Sets the contract_end_date of this TrusteeBillingOverview.
        Date-time the contract ends. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param contract_end_date: The contract_end_date of this TrusteeBillingOverview.
        :type: datetime
        """
        
        self._contract_end_date = contract_end_date

    @property
    def minimum_monthly_amount(self):
        """
        Gets the minimum_monthly_amount of this TrusteeBillingOverview.
        Minimum amount that will be charged for the month

        :return: The minimum_monthly_amount of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._minimum_monthly_amount

    @minimum_monthly_amount.setter
    def minimum_monthly_amount(self, minimum_monthly_amount):
        """
        Sets the minimum_monthly_amount of this TrusteeBillingOverview.
        Minimum amount that will be charged for the month

        :param minimum_monthly_amount: The minimum_monthly_amount of this TrusteeBillingOverview.
        :type: str
        """
        
        self._minimum_monthly_amount = minimum_monthly_amount

    @property
    def in_ramp_period(self):
        """
        Gets the in_ramp_period of this TrusteeBillingOverview.


        :return: The in_ramp_period of this TrusteeBillingOverview.
        :rtype: bool
        """
        return self._in_ramp_period

    @in_ramp_period.setter
    def in_ramp_period(self, in_ramp_period):
        """
        Sets the in_ramp_period of this TrusteeBillingOverview.


        :param in_ramp_period: The in_ramp_period of this TrusteeBillingOverview.
        :type: bool
        """
        
        self._in_ramp_period = in_ramp_period

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TrusteeBillingOverview.
        The URI for this object

        :return: The self_uri of this TrusteeBillingOverview.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TrusteeBillingOverview.
        The URI for this object

        :param self_uri: The self_uri of this TrusteeBillingOverview.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class HistoryEntry(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        HistoryEntry - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'resource': 'str',
            'timestamp': 'datetime',
            'user': 'User',
            'client': 'DomainEntityRef',
            'version': 'str',
            'secure': 'bool'
        }

        self.attribute_map = {
            'action': 'action',
            'resource': 'resource',
            'timestamp': 'timestamp',
            'user': 'user',
            'client': 'client',
            'version': 'version',
            'secure': 'secure'
        }

        self._action = None
        self._resource = None
        self._timestamp = None
        self._user = None
        self._client = None
        self._version = None
        self._secure = None

    @property
    def action(self):
        """
        Gets the action of this HistoryEntry.
        The action performed

        :return: The action of this HistoryEntry.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this HistoryEntry.
        The action performed

        :param action: The action of this HistoryEntry.
        :type: str
        """
        allowed_values = ["CHECKIN", "CHECKOUT", "CREATE", "DEACTIVATE", "DEBUG", "DELETE", "PUBLISH", "REVERT", "SAVE", "TRANSCODE", "UPDATE", "UPLOAD"]
        if action.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for action -> " + action)
            self._action = "outdated_sdk_version"
        else:
            self._action = action

    @property
    def resource(self):
        """
        Gets the resource of this HistoryEntry.
        For actions performed not on the item itself, but on a sub-item, this field identifies the sub-item by name.  For example, for actions performed on prompt resources, this will be the prompt resource name.

        :return: The resource of this HistoryEntry.
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """
        Sets the resource of this HistoryEntry.
        For actions performed not on the item itself, but on a sub-item, this field identifies the sub-item by name.  For example, for actions performed on prompt resources, this will be the prompt resource name.

        :param resource: The resource of this HistoryEntry.
        :type: str
        """
        
        self._resource = resource

    @property
    def timestamp(self):
        """
        Gets the timestamp of this HistoryEntry.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The timestamp of this HistoryEntry.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this HistoryEntry.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param timestamp: The timestamp of this HistoryEntry.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def user(self):
        """
        Gets the user of this HistoryEntry.
        User associated with this entry.

        :return: The user of this HistoryEntry.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this HistoryEntry.
        User associated with this entry.

        :param user: The user of this HistoryEntry.
        :type: User
        """
        
        self._user = user

    @property
    def client(self):
        """
        Gets the client of this HistoryEntry.
        OAuth client associated with this entry.

        :return: The client of this HistoryEntry.
        :rtype: DomainEntityRef
        """
        return self._client

    @client.setter
    def client(self, client):
        """
        Sets the client of this HistoryEntry.
        OAuth client associated with this entry.

        :param client: The client of this HistoryEntry.
        :type: DomainEntityRef
        """
        
        self._client = client

    @property
    def version(self):
        """
        Gets the version of this HistoryEntry.


        :return: The version of this HistoryEntry.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this HistoryEntry.


        :param version: The version of this HistoryEntry.
        :type: str
        """
        
        self._version = version

    @property
    def secure(self):
        """
        Gets the secure of this HistoryEntry.


        :return: The secure of this HistoryEntry.
        :rtype: bool
        """
        return self._secure

    @secure.setter
    def secure(self, secure):
        """
        Sets the secure of this HistoryEntry.


        :param secure: The secure of this HistoryEntry.
        :type: bool
        """
        
        self._secure = secure

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class RecordingTranscodeCompleteTopicRecording(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecordingTranscodeCompleteTopicRecording - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'conversation_id': 'str',
            'file_state': 'str',
            'media_uris': 'list[RecordingTranscodeCompleteTopicMediaResult]',
            'estimated_transcode_time_ms': 'float',
            'actual_transcode_time_ms': 'float'
        }

        self.attribute_map = {
            'id': 'id',
            'conversation_id': 'conversationId',
            'file_state': 'fileState',
            'media_uris': 'mediaUris',
            'estimated_transcode_time_ms': 'estimatedTranscodeTimeMs',
            'actual_transcode_time_ms': 'actualTranscodeTimeMs'
        }

        self._id = None
        self._conversation_id = None
        self._file_state = None
        self._media_uris = None
        self._estimated_transcode_time_ms = None
        self._actual_transcode_time_ms = None

    @property
    def id(self):
        """
        Gets the id of this RecordingTranscodeCompleteTopicRecording.


        :return: The id of this RecordingTranscodeCompleteTopicRecording.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecordingTranscodeCompleteTopicRecording.


        :param id: The id of this RecordingTranscodeCompleteTopicRecording.
        :type: str
        """
        
        self._id = id

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this RecordingTranscodeCompleteTopicRecording.


        :return: The conversation_id of this RecordingTranscodeCompleteTopicRecording.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this RecordingTranscodeCompleteTopicRecording.


        :param conversation_id: The conversation_id of this RecordingTranscodeCompleteTopicRecording.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def file_state(self):
        """
        Gets the file_state of this RecordingTranscodeCompleteTopicRecording.


        :return: The file_state of this RecordingTranscodeCompleteTopicRecording.
        :rtype: str
        """
        return self._file_state

    @file_state.setter
    def file_state(self, file_state):
        """
        Sets the file_state of this RecordingTranscodeCompleteTopicRecording.


        :param file_state: The file_state of this RecordingTranscodeCompleteTopicRecording.
        :type: str
        """
        
        self._file_state = file_state

    @property
    def media_uris(self):
        """
        Gets the media_uris of this RecordingTranscodeCompleteTopicRecording.


        :return: The media_uris of this RecordingTranscodeCompleteTopicRecording.
        :rtype: list[RecordingTranscodeCompleteTopicMediaResult]
        """
        return self._media_uris

    @media_uris.setter
    def media_uris(self, media_uris):
        """
        Sets the media_uris of this RecordingTranscodeCompleteTopicRecording.


        :param media_uris: The media_uris of this RecordingTranscodeCompleteTopicRecording.
        :type: list[RecordingTranscodeCompleteTopicMediaResult]
        """
        
        self._media_uris = media_uris

    @property
    def estimated_transcode_time_ms(self):
        """
        Gets the estimated_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.


        :return: The estimated_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.
        :rtype: float
        """
        return self._estimated_transcode_time_ms

    @estimated_transcode_time_ms.setter
    def estimated_transcode_time_ms(self, estimated_transcode_time_ms):
        """
        Sets the estimated_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.


        :param estimated_transcode_time_ms: The estimated_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.
        :type: float
        """
        
        self._estimated_transcode_time_ms = estimated_transcode_time_ms

    @property
    def actual_transcode_time_ms(self):
        """
        Gets the actual_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.


        :return: The actual_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.
        :rtype: float
        """
        return self._actual_transcode_time_ms

    @actual_transcode_time_ms.setter
    def actual_transcode_time_ms(self, actual_transcode_time_ms):
        """
        Sets the actual_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.


        :param actual_transcode_time_ms: The actual_transcode_time_ms of this RecordingTranscodeCompleteTopicRecording.
        :type: float
        """
        
        self._actual_transcode_time_ms = actual_transcode_time_ms

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DIDNumber(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DIDNumber - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'number': 'str',
            'assigned': 'bool',
            'did_pool': 'AddressableEntityRef',
            'owner': 'DomainEntityRef',
            'owner_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'number': 'number',
            'assigned': 'assigned',
            'did_pool': 'didPool',
            'owner': 'owner',
            'owner_type': 'ownerType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._number = None
        self._assigned = None
        self._did_pool = None
        self._owner = None
        self._owner_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DIDNumber.
        The globally unique identifier for the object.

        :return: The id of this DIDNumber.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DIDNumber.
        The globally unique identifier for the object.

        :param id: The id of this DIDNumber.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DIDNumber.


        :return: The name of this DIDNumber.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DIDNumber.


        :param name: The name of this DIDNumber.
        :type: str
        """
        
        self._name = name

    @property
    def number(self):
        """
        Gets the number of this DIDNumber.
        The number of the DID formatted as E164.

        :return: The number of this DIDNumber.
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this DIDNumber.
        The number of the DID formatted as E164.

        :param number: The number of this DIDNumber.
        :type: str
        """
        
        self._number = number

    @property
    def assigned(self):
        """
        Gets the assigned of this DIDNumber.
        True if this DID is assigned to an entity.  False otherwise.

        :return: The assigned of this DIDNumber.
        :rtype: bool
        """
        return self._assigned

    @assigned.setter
    def assigned(self, assigned):
        """
        Sets the assigned of this DIDNumber.
        True if this DID is assigned to an entity.  False otherwise.

        :param assigned: The assigned of this DIDNumber.
        :type: bool
        """
        
        self._assigned = assigned

    @property
    def did_pool(self):
        """
        Gets the did_pool of this DIDNumber.
        A Uri reference to the DID Pool this DID is a part of.

        :return: The did_pool of this DIDNumber.
        :rtype: AddressableEntityRef
        """
        return self._did_pool

    @did_pool.setter
    def did_pool(self, did_pool):
        """
        Sets the did_pool of this DIDNumber.
        A Uri reference to the DID Pool this DID is a part of.

        :param did_pool: The did_pool of this DIDNumber.
        :type: AddressableEntityRef
        """
        
        self._did_pool = did_pool

    @property
    def owner(self):
        """
        Gets the owner of this DIDNumber.
        A Uri reference to the owner of this DID.  The owner's type can be found in ownerType.  If the DID is unassigned, this will be NULL.

        :return: The owner of this DIDNumber.
        :rtype: DomainEntityRef
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DIDNumber.
        A Uri reference to the owner of this DID.  The owner's type can be found in ownerType.  If the DID is unassigned, this will be NULL.

        :param owner: The owner of this DIDNumber.
        :type: DomainEntityRef
        """
        
        self._owner = owner

    @property
    def owner_type(self):
        """
        Gets the owner_type of this DIDNumber.
        The type of the entity that owns this DID.  If the DID is unassigned, this will be NULL.

        :return: The owner_type of this DIDNumber.
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """
        Sets the owner_type of this DIDNumber.
        The type of the entity that owns this DID.  If the DID is unassigned, this will be NULL.

        :param owner_type: The owner_type of this DIDNumber.
        :type: str
        """
        allowed_values = ["USER", "PHONE", "IVR_CONFIG", "GROUP"]
        if owner_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for owner_type -> " + owner_type)
            self._owner_type = "outdated_sdk_version"
        else:
            self._owner_type = owner_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DIDNumber.
        The URI for this object

        :return: The self_uri of this DIDNumber.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DIDNumber.
        The URI for this object

        :param self_uri: The self_uri of this DIDNumber.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EdgeMetrics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EdgeMetrics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'edge': 'DomainEntityRef',
            'event_time': 'datetime',
            'up_time_msec': 'int',
            'processors': 'list[EdgeMetricsProcessor]',
            'memory': 'list[EdgeMetricsMemory]',
            'disks': 'list[EdgeMetricsDisk]',
            'subsystems': 'list[EdgeMetricsSubsystem]',
            'networks': 'list[EdgeMetricsNetwork]'
        }

        self.attribute_map = {
            'edge': 'edge',
            'event_time': 'eventTime',
            'up_time_msec': 'upTimeMsec',
            'processors': 'processors',
            'memory': 'memory',
            'disks': 'disks',
            'subsystems': 'subsystems',
            'networks': 'networks'
        }

        self._edge = None
        self._event_time = None
        self._up_time_msec = None
        self._processors = None
        self._memory = None
        self._disks = None
        self._subsystems = None
        self._networks = None

    @property
    def edge(self):
        """
        Gets the edge of this EdgeMetrics.


        :return: The edge of this EdgeMetrics.
        :rtype: DomainEntityRef
        """
        return self._edge

    @edge.setter
    def edge(self, edge):
        """
        Sets the edge of this EdgeMetrics.


        :param edge: The edge of this EdgeMetrics.
        :type: DomainEntityRef
        """
        
        self._edge = edge

    @property
    def event_time(self):
        """
        Gets the event_time of this EdgeMetrics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The event_time of this EdgeMetrics.
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this EdgeMetrics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param event_time: The event_time of this EdgeMetrics.
        :type: datetime
        """
        
        self._event_time = event_time

    @property
    def up_time_msec(self):
        """
        Gets the up_time_msec of this EdgeMetrics.


        :return: The up_time_msec of this EdgeMetrics.
        :rtype: int
        """
        return self._up_time_msec

    @up_time_msec.setter
    def up_time_msec(self, up_time_msec):
        """
        Sets the up_time_msec of this EdgeMetrics.


        :param up_time_msec: The up_time_msec of this EdgeMetrics.
        :type: int
        """
        
        self._up_time_msec = up_time_msec

    @property
    def processors(self):
        """
        Gets the processors of this EdgeMetrics.


        :return: The processors of this EdgeMetrics.
        :rtype: list[EdgeMetricsProcessor]
        """
        return self._processors

    @processors.setter
    def processors(self, processors):
        """
        Sets the processors of this EdgeMetrics.


        :param processors: The processors of this EdgeMetrics.
        :type: list[EdgeMetricsProcessor]
        """
        
        self._processors = processors

    @property
    def memory(self):
        """
        Gets the memory of this EdgeMetrics.


        :return: The memory of this EdgeMetrics.
        :rtype: list[EdgeMetricsMemory]
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """
        Sets the memory of this EdgeMetrics.


        :param memory: The memory of this EdgeMetrics.
        :type: list[EdgeMetricsMemory]
        """
        
        self._memory = memory

    @property
    def disks(self):
        """
        Gets the disks of this EdgeMetrics.


        :return: The disks of this EdgeMetrics.
        :rtype: list[EdgeMetricsDisk]
        """
        return self._disks

    @disks.setter
    def disks(self, disks):
        """
        Sets the disks of this EdgeMetrics.


        :param disks: The disks of this EdgeMetrics.
        :type: list[EdgeMetricsDisk]
        """
        
        self._disks = disks

    @property
    def subsystems(self):
        """
        Gets the subsystems of this EdgeMetrics.


        :return: The subsystems of this EdgeMetrics.
        :rtype: list[EdgeMetricsSubsystem]
        """
        return self._subsystems

    @subsystems.setter
    def subsystems(self, subsystems):
        """
        Sets the subsystems of this EdgeMetrics.


        :param subsystems: The subsystems of this EdgeMetrics.
        :type: list[EdgeMetricsSubsystem]
        """
        
        self._subsystems = subsystems

    @property
    def networks(self):
        """
        Gets the networks of this EdgeMetrics.


        :return: The networks of this EdgeMetrics.
        :rtype: list[EdgeMetricsNetwork]
        """
        return self._networks

    @networks.setter
    def networks(self, networks):
        """
        Sets the networks of this EdgeMetrics.


        :param networks: The networks of this EdgeMetrics.
        :type: list[EdgeMetricsNetwork]
        """
        
        self._networks = networks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BulkErrorExternalOrganization(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BulkErrorExternalOrganization - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'code': 'str',
            'message': 'str',
            'status': 'int',
            'retryable': 'bool',
            'entity': 'ExternalOrganization',
            'details': 'list[BulkErrorDetail]'
        }

        self.attribute_map = {
            'code': 'code',
            'message': 'message',
            'status': 'status',
            'retryable': 'retryable',
            'entity': 'entity',
            'details': 'details'
        }

        self._code = None
        self._message = None
        self._status = None
        self._retryable = None
        self._entity = None
        self._details = None

    @property
    def code(self):
        """
        Gets the code of this BulkErrorExternalOrganization.


        :return: The code of this BulkErrorExternalOrganization.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this BulkErrorExternalOrganization.


        :param code: The code of this BulkErrorExternalOrganization.
        :type: str
        """
        
        self._code = code

    @property
    def message(self):
        """
        Gets the message of this BulkErrorExternalOrganization.


        :return: The message of this BulkErrorExternalOrganization.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this BulkErrorExternalOrganization.


        :param message: The message of this BulkErrorExternalOrganization.
        :type: str
        """
        
        self._message = message

    @property
    def status(self):
        """
        Gets the status of this BulkErrorExternalOrganization.


        :return: The status of this BulkErrorExternalOrganization.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this BulkErrorExternalOrganization.


        :param status: The status of this BulkErrorExternalOrganization.
        :type: int
        """
        
        self._status = status

    @property
    def retryable(self):
        """
        Gets the retryable of this BulkErrorExternalOrganization.


        :return: The retryable of this BulkErrorExternalOrganization.
        :rtype: bool
        """
        return self._retryable

    @retryable.setter
    def retryable(self, retryable):
        """
        Sets the retryable of this BulkErrorExternalOrganization.


        :param retryable: The retryable of this BulkErrorExternalOrganization.
        :type: bool
        """
        
        self._retryable = retryable

    @property
    def entity(self):
        """
        Gets the entity of this BulkErrorExternalOrganization.


        :return: The entity of this BulkErrorExternalOrganization.
        :rtype: ExternalOrganization
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """
        Sets the entity of this BulkErrorExternalOrganization.


        :param entity: The entity of this BulkErrorExternalOrganization.
        :type: ExternalOrganization
        """
        
        self._entity = entity

    @property
    def details(self):
        """
        Gets the details of this BulkErrorExternalOrganization.


        :return: The details of this BulkErrorExternalOrganization.
        :rtype: list[BulkErrorDetail]
        """
        return self._details

    @details.setter
    def details(self, details):
        """
        Sets the details of this BulkErrorExternalOrganization.


        :param details: The details of this BulkErrorExternalOrganization.
        :type: list[BulkErrorDetail]
        """
        
        self._details = details

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class FlowRuntimeExecution(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowRuntimeExecution - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'flow_version': 'FlowVersion',
            'date_launched': 'datetime',
            'status': 'str',
            'date_completed': 'datetime',
            'completion_reason': 'str',
            'flow_error_info': 'ErrorBody',
            'output_data': 'dict(str, object)',
            'conversation': 'DomainEntityRef',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'flow_version': 'flowVersion',
            'date_launched': 'dateLaunched',
            'status': 'status',
            'date_completed': 'dateCompleted',
            'completion_reason': 'completionReason',
            'flow_error_info': 'flowErrorInfo',
            'output_data': 'outputData',
            'conversation': 'conversation',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._flow_version = None
        self._date_launched = None
        self._status = None
        self._date_completed = None
        self._completion_reason = None
        self._flow_error_info = None
        self._output_data = None
        self._conversation = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FlowRuntimeExecution.
        The flow execution ID

        :return: The id of this FlowRuntimeExecution.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowRuntimeExecution.
        The flow execution ID

        :param id: The id of this FlowRuntimeExecution.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowRuntimeExecution.
        The flow execution name.

        :return: The name of this FlowRuntimeExecution.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowRuntimeExecution.
        The flow execution name.

        :param name: The name of this FlowRuntimeExecution.
        :type: str
        """
        
        self._name = name

    @property
    def flow_version(self):
        """
        Gets the flow_version of this FlowRuntimeExecution.
        The Version of the flow definition of the flow execution.

        :return: The flow_version of this FlowRuntimeExecution.
        :rtype: FlowVersion
        """
        return self._flow_version

    @flow_version.setter
    def flow_version(self, flow_version):
        """
        Sets the flow_version of this FlowRuntimeExecution.
        The Version of the flow definition of the flow execution.

        :param flow_version: The flow_version of this FlowRuntimeExecution.
        :type: FlowVersion
        """
        
        self._flow_version = flow_version

    @property
    def date_launched(self):
        """
        Gets the date_launched of this FlowRuntimeExecution.
        The time the flow was launched. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_launched of this FlowRuntimeExecution.
        :rtype: datetime
        """
        return self._date_launched

    @date_launched.setter
    def date_launched(self, date_launched):
        """
        Sets the date_launched of this FlowRuntimeExecution.
        The time the flow was launched. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_launched: The date_launched of this FlowRuntimeExecution.
        :type: datetime
        """
        
        self._date_launched = date_launched

    @property
    def status(self):
        """
        Gets the status of this FlowRuntimeExecution.
        The flow's running status, which indicates whether the flow is running normally or completed, etc.

        :return: The status of this FlowRuntimeExecution.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this FlowRuntimeExecution.
        The flow's running status, which indicates whether the flow is running normally or completed, etc.

        :param status: The status of this FlowRuntimeExecution.
        :type: str
        """
        allowed_values = ["UNKNOWN", "RUNNING", "ERROR", "TERMINATED", "COMPLETED", "FAILED"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def date_completed(self):
        """
        Gets the date_completed of this FlowRuntimeExecution.
        The time the flow completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_completed of this FlowRuntimeExecution.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this FlowRuntimeExecution.
        The time the flow completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_completed: The date_completed of this FlowRuntimeExecution.
        :type: datetime
        """
        
        self._date_completed = date_completed

    @property
    def completion_reason(self):
        """
        Gets the completion_reason of this FlowRuntimeExecution.
        The completion reason set at the flow completion time, if applicable.

        :return: The completion_reason of this FlowRuntimeExecution.
        :rtype: str
        """
        return self._completion_reason

    @completion_reason.setter
    def completion_reason(self, completion_reason):
        """
        Sets the completion_reason of this FlowRuntimeExecution.
        The completion reason set at the flow completion time, if applicable.

        :param completion_reason: The completion_reason of this FlowRuntimeExecution.
        :type: str
        """
        
        self._completion_reason = completion_reason

    @property
    def flow_error_info(self):
        """
        Gets the flow_error_info of this FlowRuntimeExecution.
        Additional information if the flow is in error

        :return: The flow_error_info of this FlowRuntimeExecution.
        :rtype: ErrorBody
        """
        return self._flow_error_info

    @flow_error_info.setter
    def flow_error_info(self, flow_error_info):
        """
        Sets the flow_error_info of this FlowRuntimeExecution.
        Additional information if the flow is in error

        :param flow_error_info: The flow_error_info of this FlowRuntimeExecution.
        :type: ErrorBody
        """
        
        self._flow_error_info = flow_error_info

    @property
    def output_data(self):
        """
        Gets the output_data of this FlowRuntimeExecution.
        List of the flow's output variables, if any. Output variables are only supplied for Completed flows.

        :return: The output_data of this FlowRuntimeExecution.
        :rtype: dict(str, object)
        """
        return self._output_data

    @output_data.setter
    def output_data(self, output_data):
        """
        Sets the output_data of this FlowRuntimeExecution.
        List of the flow's output variables, if any. Output variables are only supplied for Completed flows.

        :param output_data: The output_data of this FlowRuntimeExecution.
        :type: dict(str, object)
        """
        
        self._output_data = output_data

    @property
    def conversation(self):
        """
        Gets the conversation of this FlowRuntimeExecution.
        The conversation to which this Flow execution is related

        :return: The conversation of this FlowRuntimeExecution.
        :rtype: DomainEntityRef
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this FlowRuntimeExecution.
        The conversation to which this Flow execution is related

        :param conversation: The conversation of this FlowRuntimeExecution.
        :type: DomainEntityRef
        """
        
        self._conversation = conversation

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowRuntimeExecution.
        The URI for this object

        :return: The self_uri of this FlowRuntimeExecution.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowRuntimeExecution.
        The URI for this object

        :param self_uri: The self_uri of this FlowRuntimeExecution.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ContactListFilterPredicate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContactListFilterPredicate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'column': 'str',
            'column_type': 'str',
            'operator': 'str',
            'value': 'str',
            'range': 'ContactListFilterRange',
            'inverted': 'bool'
        }

        self.attribute_map = {
            'column': 'column',
            'column_type': 'columnType',
            'operator': 'operator',
            'value': 'value',
            'range': 'range',
            'inverted': 'inverted'
        }

        self._column = None
        self._column_type = None
        self._operator = None
        self._value = None
        self._range = None
        self._inverted = None

    @property
    def column(self):
        """
        Gets the column of this ContactListFilterPredicate.
        Contact list column from the ContactListFilter's contactList.

        :return: The column of this ContactListFilterPredicate.
        :rtype: str
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this ContactListFilterPredicate.
        Contact list column from the ContactListFilter's contactList.

        :param column: The column of this ContactListFilterPredicate.
        :type: str
        """
        
        self._column = column

    @property
    def column_type(self):
        """
        Gets the column_type of this ContactListFilterPredicate.
        The type of data in the contact column.

        :return: The column_type of this ContactListFilterPredicate.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this ContactListFilterPredicate.
        The type of data in the contact column.

        :param column_type: The column_type of this ContactListFilterPredicate.
        :type: str
        """
        allowed_values = ["numeric", "alphabetic"]
        if column_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for column_type -> " + column_type)
            self._column_type = "outdated_sdk_version"
        else:
            self._column_type = column_type

    @property
    def operator(self):
        """
        Gets the operator of this ContactListFilterPredicate.
        The operator for this ContactListFilterPredicate.

        :return: The operator of this ContactListFilterPredicate.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this ContactListFilterPredicate.
        The operator for this ContactListFilterPredicate.

        :param operator: The operator of this ContactListFilterPredicate.
        :type: str
        """
        allowed_values = ["EQUALS", "LESS_THAN", "LESS_THAN_EQUALS", "GREATER_THAN", "GREATER_THAN_EQUALS", "CONTAINS", "BEGINS_WITH", "ENDS_WITH", "BEFORE", "AFTER", "BETWEEN", "IN"]
        if operator.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for operator -> " + operator)
            self._operator = "outdated_sdk_version"
        else:
            self._operator = operator

    @property
    def value(self):
        """
        Gets the value of this ContactListFilterPredicate.
        Value with which to compare the contact's data. This could be text, a number, or a relative time. A value for relative time should follow the format PxxDTyyHzzM, where xx, yy, and zz specify the days, hours and minutes. For example, a value of P01DT08H30M corresponds to 1 day, 8 hours, and 30 minutes from now. To specify a time in the past, include a negative sign before each numeric value. For example, a value of P-01DT-08H-30M corresponds to 1 day, 8 hours, and 30 minutes in the past. You can also do things like P01DT00H-30M, which would correspond to 23 hours and 30 minutes from now (1 day - 30 minutes).

        :return: The value of this ContactListFilterPredicate.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ContactListFilterPredicate.
        Value with which to compare the contact's data. This could be text, a number, or a relative time. A value for relative time should follow the format PxxDTyyHzzM, where xx, yy, and zz specify the days, hours and minutes. For example, a value of P01DT08H30M corresponds to 1 day, 8 hours, and 30 minutes from now. To specify a time in the past, include a negative sign before each numeric value. For example, a value of P-01DT-08H-30M corresponds to 1 day, 8 hours, and 30 minutes in the past. You can also do things like P01DT00H-30M, which would correspond to 23 hours and 30 minutes from now (1 day - 30 minutes).

        :param value: The value of this ContactListFilterPredicate.
        :type: str
        """
        
        self._value = value

    @property
    def range(self):
        """
        Gets the range of this ContactListFilterPredicate.
        A range of values. Required for operators BETWEEN and IN.

        :return: The range of this ContactListFilterPredicate.
        :rtype: ContactListFilterRange
        """
        return self._range

    @range.setter
    def range(self, range):
        """
        Sets the range of this ContactListFilterPredicate.
        A range of values. Required for operators BETWEEN and IN.

        :param range: The range of this ContactListFilterPredicate.
        :type: ContactListFilterRange
        """
        
        self._range = range

    @property
    def inverted(self):
        """
        Gets the inverted of this ContactListFilterPredicate.
        Inverts the result of the predicate (i.e., if the predicate returns true, inverting it will return false).

        :return: The inverted of this ContactListFilterPredicate.
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """
        Sets the inverted of this ContactListFilterPredicate.
        Inverts the result of the predicate (i.e., if the predicate returns true, inverting it will return false).

        :param inverted: The inverted of this ContactListFilterPredicate.
        :type: bool
        """
        
        self._inverted = inverted

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'division': 'OutboundMessagingMessagingCampaignConfigChangeUriReference',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'campaign_status': 'str',
            'callable_time_set': 'OutboundMessagingMessagingCampaignConfigChangeUriReference',
            'contact_list': 'OutboundMessagingMessagingCampaignConfigChangeUriReference',
            'dnc_lists': 'list[OutboundMessagingMessagingCampaignConfigChangeUriReference]',
            'contact_list_filters': 'list[OutboundMessagingMessagingCampaignConfigChangeUriReference]',
            'always_running': 'bool',
            'contact_sorts': 'list[OutboundMessagingMessagingCampaignConfigChangeContactSort]',
            'messages_per_minute': 'int',
            'sms_config': 'OutboundMessagingMessagingCampaignConfigChangeSmsConfig',
            'errors': 'list[OutboundMessagingMessagingCampaignConfigChangeErrorDetail]'
        }

        self.attribute_map = {
            'id': 'id',
            'division': 'division',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'campaign_status': 'campaignStatus',
            'callable_time_set': 'callableTimeSet',
            'contact_list': 'contactList',
            'dnc_lists': 'dncLists',
            'contact_list_filters': 'contactListFilters',
            'always_running': 'alwaysRunning',
            'contact_sorts': 'contactSorts',
            'messages_per_minute': 'messagesPerMinute',
            'sms_config': 'smsConfig',
            'errors': 'errors'
        }

        self._id = None
        self._division = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._campaign_status = None
        self._callable_time_set = None
        self._contact_list = None
        self._dnc_lists = None
        self._contact_list_filters = None
        self._always_running = None
        self._contact_sorts = None
        self._messages_per_minute = None
        self._sms_config = None
        self._errors = None

    @property
    def id(self):
        """
        Gets the id of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The id of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param id: The id of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: str
        """
        
        self._id = id

    @property
    def division(self):
        """
        Gets the division of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The division of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param division: The division of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        
        self._division = division

    @property
    def name(self):
        """
        Gets the name of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The name of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param name: The name of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The date_created of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param date_created: The date_created of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The date_modified of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param date_modified: The date_modified of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The version of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param version: The version of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: int
        """
        
        self._version = version

    @property
    def campaign_status(self):
        """
        Gets the campaign_status of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The campaign_status of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: str
        """
        return self._campaign_status

    @campaign_status.setter
    def campaign_status(self, campaign_status):
        """
        Sets the campaign_status of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param campaign_status: The campaign_status of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: str
        """
        allowed_values = ["ON", "OFF", "COMPLETE", "STOPPING", "INVALID"]
        if campaign_status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for campaign_status -> " + campaign_status)
            self._campaign_status = "outdated_sdk_version"
        else:
            self._campaign_status = campaign_status

    @property
    def callable_time_set(self):
        """
        Gets the callable_time_set of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The callable_time_set of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        return self._callable_time_set

    @callable_time_set.setter
    def callable_time_set(self, callable_time_set):
        """
        Sets the callable_time_set of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param callable_time_set: The callable_time_set of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        
        self._callable_time_set = callable_time_set

    @property
    def contact_list(self):
        """
        Gets the contact_list of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The contact_list of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param contact_list: The contact_list of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: OutboundMessagingMessagingCampaignConfigChangeUriReference
        """
        
        self._contact_list = contact_list

    @property
    def dnc_lists(self):
        """
        Gets the dnc_lists of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The dnc_lists of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: list[OutboundMessagingMessagingCampaignConfigChangeUriReference]
        """
        return self._dnc_lists

    @dnc_lists.setter
    def dnc_lists(self, dnc_lists):
        """
        Sets the dnc_lists of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param dnc_lists: The dnc_lists of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: list[OutboundMessagingMessagingCampaignConfigChangeUriReference]
        """
        
        self._dnc_lists = dnc_lists

    @property
    def contact_list_filters(self):
        """
        Gets the contact_list_filters of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The contact_list_filters of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: list[OutboundMessagingMessagingCampaignConfigChangeUriReference]
        """
        return self._contact_list_filters

    @contact_list_filters.setter
    def contact_list_filters(self, contact_list_filters):
        """
        Sets the contact_list_filters of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param contact_list_filters: The contact_list_filters of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: list[OutboundMessagingMessagingCampaignConfigChangeUriReference]
        """
        
        self._contact_list_filters = contact_list_filters

    @property
    def always_running(self):
        """
        Gets the always_running of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The always_running of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: bool
        """
        return self._always_running

    @always_running.setter
    def always_running(self, always_running):
        """
        Sets the always_running of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param always_running: The always_running of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: bool
        """
        
        self._always_running = always_running

    @property
    def contact_sorts(self):
        """
        Gets the contact_sorts of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The contact_sorts of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: list[OutboundMessagingMessagingCampaignConfigChangeContactSort]
        """
        return self._contact_sorts

    @contact_sorts.setter
    def contact_sorts(self, contact_sorts):
        """
        Sets the contact_sorts of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param contact_sorts: The contact_sorts of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: list[OutboundMessagingMessagingCampaignConfigChangeContactSort]
        """
        
        self._contact_sorts = contact_sorts

    @property
    def messages_per_minute(self):
        """
        Gets the messages_per_minute of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The messages_per_minute of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: int
        """
        return self._messages_per_minute

    @messages_per_minute.setter
    def messages_per_minute(self, messages_per_minute):
        """
        Sets the messages_per_minute of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param messages_per_minute: The messages_per_minute of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: int
        """
        
        self._messages_per_minute = messages_per_minute

    @property
    def sms_config(self):
        """
        Gets the sms_config of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The sms_config of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: OutboundMessagingMessagingCampaignConfigChangeSmsConfig
        """
        return self._sms_config

    @sms_config.setter
    def sms_config(self, sms_config):
        """
        Sets the sms_config of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param sms_config: The sms_config of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: OutboundMessagingMessagingCampaignConfigChangeSmsConfig
        """
        
        self._sms_config = sms_config

    @property
    def errors(self):
        """
        Gets the errors of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :return: The errors of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :rtype: list[OutboundMessagingMessagingCampaignConfigChangeErrorDetail]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """
        Sets the errors of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.


        :param errors: The errors of this OutboundMessagingMessagingCampaignConfigChangeMessagingCampaign.
        :type: list[OutboundMessagingMessagingCampaignConfigChangeErrorDetail]
        """
        
        self._errors = errors

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KlaxonHeartBeatRulesTopicHeartBeatRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KlaxonHeartBeatRulesTopicHeartBeatRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'sender_id': 'str',
            'heart_beat_timeout_in_minutes': 'float',
            'enabled': 'bool',
            'in_alarm': 'bool',
            'notification_users': 'list[KlaxonHeartBeatRulesTopicNotificationUser]',
            'alert_types': 'list[str]',
            'rule_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'sender_id': 'senderId',
            'heart_beat_timeout_in_minutes': 'heartBeatTimeoutInMinutes',
            'enabled': 'enabled',
            'in_alarm': 'inAlarm',
            'notification_users': 'notificationUsers',
            'alert_types': 'alertTypes',
            'rule_type': 'ruleType'
        }

        self._id = None
        self._name = None
        self._sender_id = None
        self._heart_beat_timeout_in_minutes = None
        self._enabled = None
        self._in_alarm = None
        self._notification_users = None
        self._alert_types = None
        self._rule_type = None

    @property
    def id(self):
        """
        Gets the id of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The id of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param id: The id of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The name of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param name: The name of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: str
        """
        
        self._name = name

    @property
    def sender_id(self):
        """
        Gets the sender_id of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The sender_id of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: str
        """
        return self._sender_id

    @sender_id.setter
    def sender_id(self, sender_id):
        """
        Sets the sender_id of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param sender_id: The sender_id of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: str
        """
        
        self._sender_id = sender_id

    @property
    def heart_beat_timeout_in_minutes(self):
        """
        Gets the heart_beat_timeout_in_minutes of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The heart_beat_timeout_in_minutes of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: float
        """
        return self._heart_beat_timeout_in_minutes

    @heart_beat_timeout_in_minutes.setter
    def heart_beat_timeout_in_minutes(self, heart_beat_timeout_in_minutes):
        """
        Sets the heart_beat_timeout_in_minutes of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param heart_beat_timeout_in_minutes: The heart_beat_timeout_in_minutes of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: float
        """
        
        self._heart_beat_timeout_in_minutes = heart_beat_timeout_in_minutes

    @property
    def enabled(self):
        """
        Gets the enabled of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The enabled of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param enabled: The enabled of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def in_alarm(self):
        """
        Gets the in_alarm of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The in_alarm of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: bool
        """
        return self._in_alarm

    @in_alarm.setter
    def in_alarm(self, in_alarm):
        """
        Sets the in_alarm of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param in_alarm: The in_alarm of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: bool
        """
        
        self._in_alarm = in_alarm

    @property
    def notification_users(self):
        """
        Gets the notification_users of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The notification_users of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: list[KlaxonHeartBeatRulesTopicNotificationUser]
        """
        return self._notification_users

    @notification_users.setter
    def notification_users(self, notification_users):
        """
        Sets the notification_users of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param notification_users: The notification_users of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: list[KlaxonHeartBeatRulesTopicNotificationUser]
        """
        
        self._notification_users = notification_users

    @property
    def alert_types(self):
        """
        Gets the alert_types of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The alert_types of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: list[str]
        """
        return self._alert_types

    @alert_types.setter
    def alert_types(self, alert_types):
        """
        Sets the alert_types of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param alert_types: The alert_types of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: list[str]
        """
        
        self._alert_types = alert_types

    @property
    def rule_type(self):
        """
        Gets the rule_type of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :return: The rule_type of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this KlaxonHeartBeatRulesTopicHeartBeatRule.


        :param rule_type: The rule_type of this KlaxonHeartBeatRulesTopicHeartBeatRule.
        :type: str
        """
        allowed_values = ["EDGE"]
        if rule_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for rule_type -> " + rule_type)
            self._rule_type = "outdated_sdk_version"
        else:
            self._rule_type = rule_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessagingRecipient(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessagingRecipient - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'nickname': 'str',
            'id': 'str',
            'id_type': 'str',
            'image': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'email': 'str'
        }

        self.attribute_map = {
            'nickname': 'nickname',
            'id': 'id',
            'id_type': 'idType',
            'image': 'image',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'email': 'email'
        }

        self._nickname = None
        self._id = None
        self._id_type = None
        self._image = None
        self._first_name = None
        self._last_name = None
        self._email = None

    @property
    def nickname(self):
        """
        Gets the nickname of this MessagingRecipient.
        Nickname/user name

        :return: The nickname of this MessagingRecipient.
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname):
        """
        Sets the nickname of this MessagingRecipient.
        Nickname/user name

        :param nickname: The nickname of this MessagingRecipient.
        :type: str
        """
        
        self._nickname = nickname

    @property
    def id(self):
        """
        Gets the id of this MessagingRecipient.
        The recipient identifier specific for particular channel/integration. This is required when sending a message.

        :return: The id of this MessagingRecipient.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessagingRecipient.
        The recipient identifier specific for particular channel/integration. This is required when sending a message.

        :param id: The id of this MessagingRecipient.
        :type: str
        """
        
        self._id = id

    @property
    def id_type(self):
        """
        Gets the id_type of this MessagingRecipient.
        The recipient identifier type. This is used to indicate the format used by the recipient identifier.

        :return: The id_type of this MessagingRecipient.
        :rtype: str
        """
        return self._id_type

    @id_type.setter
    def id_type(self, id_type):
        """
        Sets the id_type of this MessagingRecipient.
        The recipient identifier type. This is used to indicate the format used by the recipient identifier.

        :param id_type: The id_type of this MessagingRecipient.
        :type: str
        """
        allowed_values = ["Email", "Phone", "Opaque"]
        if id_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for id_type -> " + id_type)
            self._id_type = "outdated_sdk_version"
        else:
            self._id_type = id_type

    @property
    def image(self):
        """
        Gets the image of this MessagingRecipient.
        Avatar image

        :return: The image of this MessagingRecipient.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """
        Sets the image of this MessagingRecipient.
        Avatar image

        :param image: The image of this MessagingRecipient.
        :type: str
        """
        
        self._image = image

    @property
    def first_name(self):
        """
        Gets the first_name of this MessagingRecipient.
        Sender's first name

        :return: The first_name of this MessagingRecipient.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this MessagingRecipient.
        Sender's first name

        :param first_name: The first_name of this MessagingRecipient.
        :type: str
        """
        
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this MessagingRecipient.
        Sender's last name

        :return: The last_name of this MessagingRecipient.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this MessagingRecipient.
        Sender's last name

        :param last_name: The last_name of this MessagingRecipient.
        :type: str
        """
        
        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this MessagingRecipient.
        Sender's email address

        :return: The email of this MessagingRecipient.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this MessagingRecipient.
        Sender's email address

        :param email: The email of this MessagingRecipient.
        :type: str
        """
        
        self._email = email

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuAgentScheduleQueryResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuAgentScheduleQueryResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user': 'UserReference',
            'shifts': 'list[BuAgentScheduleShift]',
            'full_day_time_off_markers': 'list[BuFullDayTimeOffMarker]',
            'work_plan': 'WorkPlanReference',
            'work_plans_per_week': 'list[WorkPlanReference]',
            'metadata': 'WfmVersionedEntityMetadata'
        }

        self.attribute_map = {
            'user': 'user',
            'shifts': 'shifts',
            'full_day_time_off_markers': 'fullDayTimeOffMarkers',
            'work_plan': 'workPlan',
            'work_plans_per_week': 'workPlansPerWeek',
            'metadata': 'metadata'
        }

        self._user = None
        self._shifts = None
        self._full_day_time_off_markers = None
        self._work_plan = None
        self._work_plans_per_week = None
        self._metadata = None

    @property
    def user(self):
        """
        Gets the user of this BuAgentScheduleQueryResponse.
        The user to whom this agent schedule applies

        :return: The user of this BuAgentScheduleQueryResponse.
        :rtype: UserReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this BuAgentScheduleQueryResponse.
        The user to whom this agent schedule applies

        :param user: The user of this BuAgentScheduleQueryResponse.
        :type: UserReference
        """
        
        self._user = user

    @property
    def shifts(self):
        """
        Gets the shifts of this BuAgentScheduleQueryResponse.
        The shift definitions for this agent schedule

        :return: The shifts of this BuAgentScheduleQueryResponse.
        :rtype: list[BuAgentScheduleShift]
        """
        return self._shifts

    @shifts.setter
    def shifts(self, shifts):
        """
        Sets the shifts of this BuAgentScheduleQueryResponse.
        The shift definitions for this agent schedule

        :param shifts: The shifts of this BuAgentScheduleQueryResponse.
        :type: list[BuAgentScheduleShift]
        """
        
        self._shifts = shifts

    @property
    def full_day_time_off_markers(self):
        """
        Gets the full_day_time_off_markers of this BuAgentScheduleQueryResponse.
        Full day time off markers which apply to this agent schedule

        :return: The full_day_time_off_markers of this BuAgentScheduleQueryResponse.
        :rtype: list[BuFullDayTimeOffMarker]
        """
        return self._full_day_time_off_markers

    @full_day_time_off_markers.setter
    def full_day_time_off_markers(self, full_day_time_off_markers):
        """
        Sets the full_day_time_off_markers of this BuAgentScheduleQueryResponse.
        Full day time off markers which apply to this agent schedule

        :param full_day_time_off_markers: The full_day_time_off_markers of this BuAgentScheduleQueryResponse.
        :type: list[BuFullDayTimeOffMarker]
        """
        
        self._full_day_time_off_markers = full_day_time_off_markers

    @property
    def work_plan(self):
        """
        Gets the work_plan of this BuAgentScheduleQueryResponse.
        The work plan for this user

        :return: The work_plan of this BuAgentScheduleQueryResponse.
        :rtype: WorkPlanReference
        """
        return self._work_plan

    @work_plan.setter
    def work_plan(self, work_plan):
        """
        Sets the work_plan of this BuAgentScheduleQueryResponse.
        The work plan for this user

        :param work_plan: The work_plan of this BuAgentScheduleQueryResponse.
        :type: WorkPlanReference
        """
        
        self._work_plan = work_plan

    @property
    def work_plans_per_week(self):
        """
        Gets the work_plans_per_week of this BuAgentScheduleQueryResponse.
        The work plans per week for this user from the work plan rotation. Null values in the list denotes that user is not part of any work plan for that week

        :return: The work_plans_per_week of this BuAgentScheduleQueryResponse.
        :rtype: list[WorkPlanReference]
        """
        return self._work_plans_per_week

    @work_plans_per_week.setter
    def work_plans_per_week(self, work_plans_per_week):
        """
        Sets the work_plans_per_week of this BuAgentScheduleQueryResponse.
        The work plans per week for this user from the work plan rotation. Null values in the list denotes that user is not part of any work plan for that week

        :param work_plans_per_week: The work_plans_per_week of this BuAgentScheduleQueryResponse.
        :type: list[WorkPlanReference]
        """
        
        self._work_plans_per_week = work_plans_per_week

    @property
    def metadata(self):
        """
        Gets the metadata of this BuAgentScheduleQueryResponse.
        Versioned entity metadata for this agent schedule

        :return: The metadata of this BuAgentScheduleQueryResponse.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this BuAgentScheduleQueryResponse.
        Versioned entity metadata for this agent schedule

        :param metadata: The metadata of this BuAgentScheduleQueryResponse.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EncryptionKey(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EncryptionKey - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'create_date': 'datetime',
            'keydata_summary': 'str',
            'user': 'User',
            'local_encryption_configuration': 'LocalEncryptionConfiguration',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'create_date': 'createDate',
            'keydata_summary': 'keydataSummary',
            'user': 'user',
            'local_encryption_configuration': 'localEncryptionConfiguration',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._create_date = None
        self._keydata_summary = None
        self._user = None
        self._local_encryption_configuration = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this EncryptionKey.
        The globally unique identifier for the object.

        :return: The id of this EncryptionKey.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this EncryptionKey.
        The globally unique identifier for the object.

        :param id: The id of this EncryptionKey.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this EncryptionKey.


        :return: The name of this EncryptionKey.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EncryptionKey.


        :param name: The name of this EncryptionKey.
        :type: str
        """
        
        self._name = name

    @property
    def create_date(self):
        """
        Gets the create_date of this EncryptionKey.
        create date of the key pair. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The create_date of this EncryptionKey.
        :rtype: datetime
        """
        return self._create_date

    @create_date.setter
    def create_date(self, create_date):
        """
        Sets the create_date of this EncryptionKey.
        create date of the key pair. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param create_date: The create_date of this EncryptionKey.
        :type: datetime
        """
        
        self._create_date = create_date

    @property
    def keydata_summary(self):
        """
        Gets the keydata_summary of this EncryptionKey.
        key data summary (base 64 encoded public key)

        :return: The keydata_summary of this EncryptionKey.
        :rtype: str
        """
        return self._keydata_summary

    @keydata_summary.setter
    def keydata_summary(self, keydata_summary):
        """
        Sets the keydata_summary of this EncryptionKey.
        key data summary (base 64 encoded public key)

        :param keydata_summary: The keydata_summary of this EncryptionKey.
        :type: str
        """
        
        self._keydata_summary = keydata_summary

    @property
    def user(self):
        """
        Gets the user of this EncryptionKey.
        user that requested generation of public key

        :return: The user of this EncryptionKey.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this EncryptionKey.
        user that requested generation of public key

        :param user: The user of this EncryptionKey.
        :type: User
        """
        
        self._user = user

    @property
    def local_encryption_configuration(self):
        """
        Gets the local_encryption_configuration of this EncryptionKey.
        Local configuration

        :return: The local_encryption_configuration of this EncryptionKey.
        :rtype: LocalEncryptionConfiguration
        """
        return self._local_encryption_configuration

    @local_encryption_configuration.setter
    def local_encryption_configuration(self, local_encryption_configuration):
        """
        Sets the local_encryption_configuration of this EncryptionKey.
        Local configuration

        :param local_encryption_configuration: The local_encryption_configuration of this EncryptionKey.
        :type: LocalEncryptionConfiguration
        """
        
        self._local_encryption_configuration = local_encryption_configuration

    @property
    def self_uri(self):
        """
        Gets the self_uri of this EncryptionKey.
        The URI for this object

        :return: The self_uri of this EncryptionKey.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this EncryptionKey.
        The URI for this object

        :param self_uri: The self_uri of this EncryptionKey.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerContactlistfilterConfigChangeContactListFilter(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerContactlistfilterConfigChangeContactListFilter - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'contact_list': 'DialerContactlistfilterConfigChangeUriReference',
            'contact_list_columns': 'list[str]',
            'clauses': 'list[DialerContactlistfilterConfigChangeFilterClause]',
            'filter_type': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'contact_list': 'contactList',
            'contact_list_columns': 'contactListColumns',
            'clauses': 'clauses',
            'filter_type': 'filterType',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._contact_list = None
        self._contact_list_columns = None
        self._clauses = None
        self._filter_type = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The id of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerContactlistfilterConfigChangeContactListFilter.


        :param id: The id of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The name of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerContactlistfilterConfigChangeContactListFilter.


        :param name: The name of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The date_created of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DialerContactlistfilterConfigChangeContactListFilter.


        :param date_created: The date_created of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The date_modified of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DialerContactlistfilterConfigChangeContactListFilter.


        :param date_modified: The date_modified of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The version of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DialerContactlistfilterConfigChangeContactListFilter.


        :param version: The version of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: int
        """
        
        self._version = version

    @property
    def contact_list(self):
        """
        Gets the contact_list of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The contact_list of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: DialerContactlistfilterConfigChangeUriReference
        """
        return self._contact_list

    @contact_list.setter
    def contact_list(self, contact_list):
        """
        Sets the contact_list of this DialerContactlistfilterConfigChangeContactListFilter.


        :param contact_list: The contact_list of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: DialerContactlistfilterConfigChangeUriReference
        """
        
        self._contact_list = contact_list

    @property
    def contact_list_columns(self):
        """
        Gets the contact_list_columns of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The contact_list_columns of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: list[str]
        """
        return self._contact_list_columns

    @contact_list_columns.setter
    def contact_list_columns(self, contact_list_columns):
        """
        Sets the contact_list_columns of this DialerContactlistfilterConfigChangeContactListFilter.


        :param contact_list_columns: The contact_list_columns of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: list[str]
        """
        
        self._contact_list_columns = contact_list_columns

    @property
    def clauses(self):
        """
        Gets the clauses of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The clauses of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: list[DialerContactlistfilterConfigChangeFilterClause]
        """
        return self._clauses

    @clauses.setter
    def clauses(self, clauses):
        """
        Sets the clauses of this DialerContactlistfilterConfigChangeContactListFilter.


        :param clauses: The clauses of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: list[DialerContactlistfilterConfigChangeFilterClause]
        """
        
        self._clauses = clauses

    @property
    def filter_type(self):
        """
        Gets the filter_type of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The filter_type of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """
        Sets the filter_type of this DialerContactlistfilterConfigChangeContactListFilter.


        :param filter_type: The filter_type of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: str
        """
        allowed_values = ["AND", "OR"]
        if filter_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for filter_type -> " + filter_type)
            self._filter_type = "outdated_sdk_version"
        else:
            self._filter_type = filter_type

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerContactlistfilterConfigChangeContactListFilter.


        :return: The additional_properties of this DialerContactlistfilterConfigChangeContactListFilter.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerContactlistfilterConfigChangeContactListFilter.


        :param additional_properties: The additional_properties of this DialerContactlistfilterConfigChangeContactListFilter.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScreenRecordingSession(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScreenRecordingSession - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'user': 'User',
            'communication_id': 'str',
            'conversation': 'Conversation',
            'start_time': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'user': 'user',
            'communication_id': 'communicationId',
            'conversation': 'conversation',
            'start_time': 'startTime',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._user = None
        self._communication_id = None
        self._conversation = None
        self._start_time = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ScreenRecordingSession.
        The globally unique identifier for the object.

        :return: The id of this ScreenRecordingSession.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScreenRecordingSession.
        The globally unique identifier for the object.

        :param id: The id of this ScreenRecordingSession.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ScreenRecordingSession.


        :return: The name of this ScreenRecordingSession.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScreenRecordingSession.


        :param name: The name of this ScreenRecordingSession.
        :type: str
        """
        
        self._name = name

    @property
    def user(self):
        """
        Gets the user of this ScreenRecordingSession.


        :return: The user of this ScreenRecordingSession.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ScreenRecordingSession.


        :param user: The user of this ScreenRecordingSession.
        :type: User
        """
        
        self._user = user

    @property
    def communication_id(self):
        """
        Gets the communication_id of this ScreenRecordingSession.
        The id of the communication that is being recorded on the conversation

        :return: The communication_id of this ScreenRecordingSession.
        :rtype: str
        """
        return self._communication_id

    @communication_id.setter
    def communication_id(self, communication_id):
        """
        Sets the communication_id of this ScreenRecordingSession.
        The id of the communication that is being recorded on the conversation

        :param communication_id: The communication_id of this ScreenRecordingSession.
        :type: str
        """
        
        self._communication_id = communication_id

    @property
    def conversation(self):
        """
        Gets the conversation of this ScreenRecordingSession.


        :return: The conversation of this ScreenRecordingSession.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this ScreenRecordingSession.


        :param conversation: The conversation of this ScreenRecordingSession.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def start_time(self):
        """
        Gets the start_time of this ScreenRecordingSession.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_time of this ScreenRecordingSession.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ScreenRecordingSession.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_time: The start_time of this ScreenRecordingSession.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ScreenRecordingSession.
        The URI for this object

        :return: The self_uri of this ScreenRecordingSession.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ScreenRecordingSession.
        The URI for this object

        :param self_uri: The self_uri of this ScreenRecordingSession.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

